//
//  AASBasicInfoFileItem.h
//
//  Created by Andreas Schwarz on Thu Apr 18 2002.
//  OS X 10.5 or later required.
/* Copyright (c) 2001-2009, Andreas Schwarz
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
 Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 Neither the names of the Andreas Schwarz or immaterial nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


#import <Cocoa/Cocoa.h>
#import "AASFileItem.h"

/* The AASBasicInfoFileItem is an AASFileItem subclass that contains some extra basic information about a file, such as the display name and whether it is a directory, application, package, and, if it is an alias or a symbolic link, the file it points to. */


/* Keys for archive dictionaries */
extern NSString *AASArchiveIsAliasKey;	// Will return an NSNumber BOOL value - YES if the file was a symbolic link or alias, NO if it was a 'real' file 



@interface AASBasicInfoFileItem : AASFileItem {
    char isApplication;
    char isVolumesDirectory;
    char isRootDirectory;
    char isDirectory;
    char isPackage;
    char isInvisible;
	char isAlias;
    
    FSRef resolvedFSRef;
    char resolvedFSRefIsValid;
    char resolvedIsDirectory;
	id resolvedFile;
    
    NSString *fileName;
    NSString *displayName;
	NSString *resolvedPath;
    CFURLRef resolvedURL;
    CFStringRef UTI;
    CFStringRef resolvedUTI;
}

/* Returns the true file name of the file (including the extension).  This is really only the last path component, so it may not work properly on things like volume names. */
- (NSString *)fileName;

/* Returns the display name of the file (this takes into account whether or not the file extension is hidden, and returns the proper name for volumes (like the root volume). */
- (NSString *)displayName;



/* If this file is an alias/symlink, this returns the path to whatever file the alias is pointing to.  Otherwise, it returns the path to this file. */
- (NSString *)resolvedPath;
/* If this file is an alias/symlink, this returns the URL to whatever file the alias is pointing to.  Otherwise, it returns the URL to this file. */
- (NSURL *)resolvedURL;
/* If the file is an alias/symlink, returns a pointer to an FSRef for the file the alias points to.  Otherwise returns a pointer to the FSRef for the file itself.  Might be null. */
- (FSRef *)resolvedFSRef;
/* If the file is an alias/symlink, returns a AASBasicInfoFileItem instance (or subclass of the same class as the reciever) for the file the alias points to.  Otherwise returns itself. */
- (id)resolvedFile;


/* Returns the UTI of the file. */
- (CFStringRef)uti;
/* If the file is an alias/symlink, returns the UTI for the file the alias points to.  Otherwise returns its own UTI. */
- (CFStringRef)resolvedUTI;


// Can be called to re-check the resolved FSRef in case this file is an alias and the file it pointed to is now gone.
// Returns YES if the file is an alias/symlink and NO otherwise
// Subclasses will want to implement this (make sure to call super) to reset any information that may hinge on what the alias points to
- (BOOL)resetAliasStatus;



/* Returns whether this file is an alias file. */
- (BOOL)isAlias;

/* A shortcut to see whether the file is an alias/symlink or a "real" file. */
- (BOOL)isRealFile;




/* Returns whether this file is an application.  This includes if it is an alias or symlink to an application. */
- (BOOL)isApplication;

/* Returns whether this file is a directory.  This includes if it is an alias or symlink to a directory.  It excludes package. */
- (BOOL)isDirectory;

/* Returns whether this file is a package.  This includes if it is an alias or symlink to a package. */
- (BOOL)isPackage;

/* The Volumes directory can be used as a cheap and dirty way to fake a Finderlike "Computer" directory, so knowing whether or not a directory is the volumes directory might be useful.  It is needed for these reasons by the above displayName and fileName methods. */
- (BOOL)isVolumesDirectory;

/* Returns whether this file is the root directoy (path "/"). */
- (BOOL)isRootDirectory;

/* Returns whether this file is invisible. (Special cases: /net/ and /home/ are returned as invisible though LaunchServices does not identify them as such. The Finder, however, does not show these items.) */
- (BOOL)isInvisible;

@end
